=============================
Module - check_package_update
=============================


This module provides for the following ansible plugin:

    * check_package_update


.. ansibleautoplugin::
   :module: validations_common/library/check_package_update.py
   :documentation: true
   :examples: true
